# spreg

[![unittests](https://github.com/pysal/spreg/workflows/.github/workflows/unittests.yml/badge.svg)](https://github.com/pysal/spreg/actions?query=workflow%3A.github%2Fworkflows%2Funittests.yml)
[![codecov](https://codecov.io/gh/pysal/spreg/branch/master/graph/badge.svg?token=9VrJpIYIl3)](https://codecov.io/gh/pysal/spreg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/spreg)
![PyPI](https://img.shields.io/pypi/v/spreg)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/spreg/badges/version.svg)](https://anaconda.org/conda-forge/spreg)
![GitHub commits since latest release (branch)](https://img.shields.io/github/commits-since/pysal/spreg/latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4421373.svg)](https://zenodo.org/record/4421373)

## PySAL Spatial Econometrics Package

`spreg`, short for “spatial regression,” is a Python package to estimate simultaneous autoregressive spatial regression models. These models are useful when modeling processes where observations interact with one another. 
This package is part of a [refactoring of PySAL](https://github.com/pysal/pysal/wiki/PEP-13:-Refactor-PySAL-Using-Submodules).

## License information

See the file "LICENSE.txt" for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.

